package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import com.ruoyi.zdsz.domain.bo.ZEngineeringInfrastructureBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringInfrastructureVo;
import com.ruoyi.zdsz.service.IZEngineeringInfrastructureService;
import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 基建工程
 *
 * @author ruoyi
 * @date 2024-01-03
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/system/engineeringInfrastructure")
public class ZEngineeringInfrastructureController extends BaseController {

    private final IZEngineeringInfrastructureService iZEngineeringInfrastructureService;

    /**
     * 查询基建工程列表
     */
    @SaCheckPermission("system:engineeringInfrastructure:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringInfrastructureVo> list(ZEngineeringInfrastructureBo bo, PageQuery pageQuery) {
        return iZEngineeringInfrastructureService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出基建工程列表
     */
    @SaCheckPermission("system:engineeringInfrastructure:export")
    @Log(title = "基建工程", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringInfrastructureBo bo, HttpServletResponse response) {
        List<ZEngineeringInfrastructureVo> list = iZEngineeringInfrastructureService.queryList(bo);
        ExcelUtil.exportExcel(list, "基建工程", ZEngineeringInfrastructureVo.class, response);
    }

    /**
     * 获取基建工程详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("system:engineeringInfrastructure:query")
    @GetMapping("/{id}")
    public R<ZEngineeringInfrastructureVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringInfrastructureService.queryById(id));
    }

    /**
     * 新增基建工程
     */
    @SaCheckPermission("system:engineeringInfrastructure:add")
    @Log(title = "基建工程", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringInfrastructureBo bo) {
        return toAjax(iZEngineeringInfrastructureService.insertByBo(bo));
    }

    /**
     * 修改基建工程
     */
    @SaCheckPermission("system:engineeringInfrastructure:edit")
    @Log(title = "基建工程", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringInfrastructureBo bo) {
        return toAjax(iZEngineeringInfrastructureService.updateByBo(bo));
    }

    /**
     * 删除基建工程
     *
     * @param ids 主键串
     */
    @SaCheckPermission("system:engineeringInfrastructure:remove")
    @Log(title = "基建工程", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringInfrastructureService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
